@@ -1,6 +1,6 @@
 /* ADSL Header file */
 
-#define VERSION		"1.10 PRE-ALPHA3 GENTOO EDITION"
+#define VERSION		"1.11 GENTOO EDITION"
 #define ROUTE_FILE	"/proc/net/route"
 #define STAT_FILE	"/var/run/ppp-mxstream.pid"
 #define TRUE 		1
@@ -11,7 +11,7 @@
 
 int start(int args, char name[10], char arg[5]);
 int stop(void);
-int restart(void);
+int restart(int argr, char name[10], char arg[5]);
 int version(void);
 
 int hasroute(const char *devicename);
